S2 contact model CV used in the paper cited below. 

## Installation 

This module is not installed by default. Add `--enable-modules=s2cm` to your './configure' command when building PLUMED to enable these features.

